pub struct SetSecretsResult {
pub success: bool,
pub error: Option<String>,
}Expand description
Result in an error when a required secret is not set
Fields
success: boolerror: Option<String>Trait Implementations
Sourceimpl Clone for SetSecretsResult
impl Clone for SetSecretsResult
Sourcefn clone(&self) -> SetSecretsResult
fn clone(&self) -> SetSecretsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetSecretsResult
impl Debug for SetSecretsResult
Sourceimpl<'de> Deserialize<'de> for SetSecretsResult
impl<'de> Deserialize<'de> for SetSecretsResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetSecretsResult
impl JsonSchema for SetSecretsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetSecretsResult
impl RefUnwindSafe for SetSecretsResult
impl Send for SetSecretsResult
impl Sync for SetSecretsResult
impl Unpin for SetSecretsResult
impl UnsafeUnpin for SetSecretsResult
impl UnwindSafe for SetSecretsResult