pub struct TraceInfo {
pub trace_id: String,
pub parent_id: Option<String>,
pub span_id: Option<String>,
}Expand description
Trace context propagated end‑to‑end for observability.
Fields
trace_id: Stringparent_id: Option<String>span_id: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TraceInfo
impl<'de> Deserialize<'de> for TraceInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceInfo
impl JsonSchema for TraceInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TraceInfo
impl RefUnwindSafe for TraceInfo
impl Send for TraceInfo
impl Sync for TraceInfo
impl Unpin for TraceInfo
impl UnsafeUnpin for TraceInfo
impl UnwindSafe for TraceInfo